<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>

  <!-- Type of object for header -->
  <xsl:variable name="objectType" select="'Object'"/>
  
  <!-- Path for object -->
  <xsl:variable name="objectPath" select="'Objects'"/>

  <!-- Root -->
  <xsl:template match="/DataDocumenter">
    <html>
      <xsl:call-template name="head" />
      <body>
        <xsl:apply-templates select="Breadcrumbs"/>
        <xsl:apply-templates select="Table | View"/>
      </body>
    </html>
  </xsl:template>

  <!-- Object information for table or view -->
  <xsl:template match="Table | View">
    <xsl:call-template name="objectInformation">
      <xsl:with-param name="objectType" select="$objectType"/>
    </xsl:call-template>

    <xsl:apply-templates select="Columns"/>
    <xsl:apply-templates select="Relations"/>
    <xsl:apply-templates select="UniqueKeys"/>
    <xsl:apply-templates select="Triggers"/>
  </xsl:template>

  <!-- Columns -->
  <xsl:template match="Columns">
    <xsl:choose>
      <xsl:when test="./*">
        <table class="table">
          <caption>Columns</caption>
          <thead>
            <tr>
              <th data-sort="int" style="width: 40px !important"> # </th>
              <xsl:choose>
                <xsl:when test="$objectType = 'Table'">
                  <th data-sort="int" style="width: 40px !important">PK</th>
                </xsl:when>
              </xsl:choose>
              <th data-sort="string" style="width: 30%">Name</th>
              <th data-sort="string" style="width: 170px">Data type</th>
              <th class="only-desktop">Description</th>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="Column"/>
          </tbody>
        </table>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Column -->
  <xsl:template match="Column">
    <tr>
      <td>
        <xsl:value-of select="OrdinalPosition"/>
      </td>
      <xsl:choose>
        <xsl:when test="$objectType = 'Table'">
          <xsl:choose>
            <xsl:when test="PK = 'PK'">
              <td>
                <i class="icon-key no-margin" title="Primary key"></i>
              </td>
            </xsl:when>
            <xsl:otherwise>
              <td></td>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
      </xsl:choose>

      <td>
        <xsl:value-of select="Name"/>
        <xsl:if test="string-length(Title)>0">
          (<xsl:value-of select="Title"/>)
        </xsl:if>
      </td>
      <td>
        <xsl:value-of select="DataType"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>

    <xsl:if test="string-length(Description)>0">
      <tr class="only-mobile">
        <td colspan="4">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Relations -->
  <xsl:template match="Relations">
    <xsl:choose>
      <xsl:when test="./* and (RelationsTo/* or RelationsFrom/*)">
        <table class="table">
          <caption>Relations</caption>
          <thead>
            <tr>
              <th data-sort="string">Foreign table</th>
              <th style="width: 40px !important"></th>
              <th data-sort="string">Primary table</th>
              <th data-sort="string" class="only-desktop">Join</th>
              <th data-sort="string" class="only-desktop">Name / Description</th>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="RelationsFrom/Relation"/>
            <xsl:apply-templates select="RelationsTo/Relation"/>
          </tbody>
        </table>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Relation to -->
  <xsl:template match="RelationsTo/Relation">
    <tr>
      <td>
        <xsl:call-template name="relationLink"/>
      </td>
      
      <!-- relation icon -->
      <td>
        <xsl:choose>
          <xsl:when test="Type = 'USER'">
            <i class="icon-user-relation no-margin" title="User defined relation"></i>
          </xsl:when>
          <xsl:otherwise>
            <i class="icon-relation no-margin" title="Relation"></i>
          </xsl:otherwise>
        </xsl:choose>
      </td>

      <td>
        <xsl:choose>
          <xsl:when test="$objectType = 'Table'">
            <xsl:value-of select="/DataDocumenter/Table/ObjectName"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="/DataDocumenter/View/ObjectName"/>
          </xsl:otherwise>
        </xsl:choose>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Join"/>
        </xsl:call-template>
      </td>
      <td class="only-desktop">
        <xsl:value-of select="Name"/>
        <xsl:if test="string-length(Description)>0">: </xsl:if>

        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>

    <tr class="only-mobile">
      <td colspan="3">
        <div>
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Join"/>
          </xsl:call-template>
        </div>

        <xsl:value-of select="Name"/>
        <xsl:if test="string-length(Description)>0">: </xsl:if>

        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:template>

  <!-- Relation from -->
  <xsl:template match="RelationsFrom/Relation">
    <tr>
      <td>
        <xsl:choose>
          <xsl:when test="$objectType = 'Table'">
            <xsl:value-of select="/DataDocumenter/Table/ObjectName"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="/DataDocumenter/View/ObjectName"/>
          </xsl:otherwise>
        </xsl:choose>
      </td>

      <!-- relation icon -->
      <td>
        <xsl:choose>
          <xsl:when test="Type = 'USER'">
            <i class="icon-user-relation no-margin" title="User defined relation"></i>
          </xsl:when>
          <xsl:otherwise>
            <i class="icon-relation no-margin" title="Relation"></i>
          </xsl:otherwise>
        </xsl:choose>
      </td>

      <td>
        <xsl:call-template name="relationLink"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Join"/>
        </xsl:call-template>
      </td>
      <td class="only-desktop">
        <xsl:value-of select="Name"/>
        <xsl:if test="string-length(Description)>0">: </xsl:if>

        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>

    <tr class="only-mobile">
      <td colspan="3">
        <div>
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Join"/>
          </xsl:call-template>
        </div>

        <xsl:value-of select="Name"/>
        <xsl:if test="string-length(Description)>0">: </xsl:if>

        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:template>

  <!-- Link for relation (for object other than current only) -->
  <xsl:template name="relationLink">
    <xsl:choose>
      <xsl:when test="ObjectObjectId != /DataDocumenter/Table/ObjectId or ObjectObjectId != /DataDocumenter/View/ObjectId">

        <xsl:choose>
          <xsl:when test="IsInCurrentModule='Yes'">

            <xsl:choose>
              <xsl:when test="$objectType = 'Table' and ObjectType = 'TABLE'">
                <a href="#{$content}/modules/{/DataDocumenter/Table/ModuleObjectId}/tables/{ObjectObjectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectObjectName"/>
                </a>
              </xsl:when>
              <xsl:when test="$objectType = 'Table' and ObjectType = 'VIEW'">
                <a href="#{$content}/modules/{/DataDocumenter/Table/ModuleObjectId}/views/{ObjectObjectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectObjectName"/>
                </a>
              </xsl:when>
              <xsl:when test="$objectType = 'View' and ObjectType = 'TABLE'">
                <a href="#{$content}/modules/{/DataDocumenter/View/ModuleObjectId}/tables/{ObjectObjectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectObjectName"/>
                </a>
              </xsl:when>
              <xsl:when test="$objectType = 'View' and ObjectType = 'VIEW'">
                <a href="#{$content}/modules/{/DataDocumenter/View/ModuleObjectId}/views/{ObjectObjectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectObjectName"/>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="ObjectObjectName"/>
              </xsl:otherwise>
            </xsl:choose>
            
          </xsl:when>
          <xsl:otherwise>

            <xsl:choose>
              <xsl:when test="ObjectType = 'TABLE'">
                <a href="#{$content}/tables/{ObjectObjectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectObjectName"/>
                </a>
              </xsl:when>
              <xsl:when test="ObjectType = 'VIEW'">
                <a href="#{$content}/views/{ObjectObjectId}{$ext}" class="ajax" data-target="#right">
                  <xsl:value-of select="ObjectObjectName"/>
                </a>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="ObjectObjectName"/>
              </xsl:otherwise>
            </xsl:choose>
            
          </xsl:otherwise>
        </xsl:choose>

      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="ObjectObjectName"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Unique keys -->
  <xsl:template match="UniqueKeys">
    <xsl:choose>
      <xsl:when test="./*">
        <table class="table">
          <caption>Unique keys</caption>
          <thead>
            <tr>
              <th data-sort="int" style="width: 40px !important"></th>
              <th data-sort="string" style="width: 20%">Key name</th>
              <th data-sort="string" style="width: 20%">Columns</th>
              <th class="only-desktop">Description</th>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="UniqueKey"/>
          </tbody>
        </table>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Unique key -->
  <xsl:template match="UniqueKey">
    <tr>
      <xsl:choose>
        <xsl:when test="Type = 'PK'">
          <td>
            <i class="icon-key no-margin" title="Primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'DisabledPK'">
          <td>
            <i class="icon-key no-margin" title="Disabled primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'UserDefinedPK'">
          <td>
            <i class="icon-user-key no-margin" title="User defined primary key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'UK'">
          <td>
            <i class="icon-unique-key no-margin" title="Unique key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'DisabledUK'">
          <td>
            <i class="icon-unique-key no-margin" title="Disabled unique key"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'UserDefinedUK'">
          <td>
            <i class="icon-user-unique-key no-margin" title="User defined unique key"></i>
          </td>
        </xsl:when>
        <xsl:otherwise>
          <td>
          </td>
        </xsl:otherwise>
      </xsl:choose>
      <td>
        <xsl:value-of select="Name"/>
      </td>
      <td>
        <xsl:value-of select="Columns"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>

    <xsl:if test="string-length(Description)>0">
      <tr class="only-mobile">
        <td colspan="3">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Triggers -->
  <xsl:template match="Triggers">
    <xsl:choose>
      <xsl:when test="./*">
        <table class="table">
          <caption>Triggers</caption>
          <thead>
            <tr>
              <th data-sort="int" style="width: 40px !important"></th>
              <th data-sort="string" style="width: 15%">Key name</th>
              <th data-sort="string" style="width: 15%">When</th>
              <th class="only-desktop">Description</th>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="Trigger"/>
          </tbody>
        </table>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Trigger -->
  <xsl:template match="Trigger">
    <tr>
      <xsl:choose>
        <xsl:when test="Type = 'ActiveTrigger'">
          <td>
            <i class="icon-trigger-active no-margin" title="Active trigger"></i>
          </td>
        </xsl:when>
        <xsl:when test="Type = 'DisabledTrigger'">
          <td>
            <i class="icon-trigger-disabled no-margin" title="Disabled trigger"></i>
          </td>
        </xsl:when>
        <xsl:otherwise>
          <td>
          </td>
        </xsl:otherwise>
      </xsl:choose>
      <td>
        <xsl:value-of select="Name"/>
      </td>
      <td>
        <xsl:value-of select="When"/>
      </td>
      <td class="only-desktop">
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="Description"/>
        </xsl:call-template>
      </td>
    </tr>

    <xsl:if test="string-length(Description)>0">
      <tr class="only-mobile">
        <td colspan="3">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Description"/>
          </xsl:call-template>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>