<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>
  
  <xsl:template match="/DataDocumenter">
    <html>
      <xsl:call-template name="head" />
      <body>
        <xsl:apply-templates select="Breadcrumbs"/>
              
        <xsl:call-template name="module"/>
        <xsl:apply-templates select="Functions|Procedures|Tables|Views"/>
        <xsl:call-template name="scripts"/>
      </body>
    </html>
  </xsl:template>

  <!-- Module information -->
  <xsl:template name="module">
    <h1><span>Module:</span> <xsl:value-of select="Module/Name"/></h1>

    <xsl:if test="/DataDocumenter/LicenseTag">
      <h1 data-tag="{/DataDocumenter/LicenseTag}" style="display: block; font-size: 42px; color: rgba(0, 0, 0, 0.4); text-transform: uppercase; margin-bottom: 10px; margin-top: -20px;"><xsl:value-of select="/DataDocumenter/LicenseTag/@type"/></h1>
    </xsl:if>

    <xsl:if test="Module/ERD != ''">
      <xsl:value-of select="Module/ERD" disable-output-escaping="yes"/>
      <script src="{$resources}/lib/ERD/js/popup.js"></script>
      <script>
        <![CDATA[
          $(function() {
            $('svg [data-msg]').popup();
          });
        ]]>
      </script>
    </xsl:if>

    <xsl:if test="Module/Description != ''">
      <div class="element description">
        <!-- The disable-output-escaping="yes" provides HTML content support. -->
        <div class="html">
          <xsl:value-of select="Module/Description" disable-output-escaping="yes"/>
        </div>
      </div>
    </xsl:if>
  </xsl:template>

  <!-- Objects' tables -->
  <xsl:template match="Functions|Procedures|Tables|Views">
    <xsl:choose>
      <xsl:when test=".!=''">
        <table class="table">
          <caption><xsl:value-of select="local-name()"/></caption>
          <thead>
            <tr>
              <th data-sort="int" style="width: 40px"> # </th>
              <th class="sorting-asc" data-sort="string"> Name </th>
            </tr>
          </thead>
          <tbody>
              <xsl:apply-templates select="Row"/>
          </tbody>
        </table>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Objects row -->
  <xsl:template match="Row">
    <tr>
      <td><xsl:value-of select="Id"/></td>
      <td><a href="#{$content}/{Name/@src}{$ext}" class="ajax" data-target="#right">
        <xsl:value-of select="Name"/>
        <xsl:if test="string-length(Title)>0">
          (<xsl:value-of select="Title"/>)
        </xsl:if>
      </a></td>
    </tr>
  </xsl:template>

  <!-- Scripts -->
  <xsl:template name="scripts">
    <script type="text/javascript" src="{$resources}/js/stupidtable.min.js"></script>
    <script type="text/javascript" src="{$resources}/js/tableSort.js"></script>
  </xsl:template>

</xsl:stylesheet>