<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
    
    <xsl:output method="html" encoding="utf-8" doctype-system="about:legacy-compat"/>
    <xsl:variable name="content" select="'content'"/><xsl:variable name="ext" select="''"/>
    <xsl:variable name="resources" select="'resources'"/>

    <!-- Default template -->
    <xsl:template match="*"></xsl:template>

    <!-- Redirection -->
    <xsl:template match="/DataDocumenter">
    	<html>
          <head>
            <meta charset="utf-8"/>
			    <meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
			    <title><xsl:value-of select="Databases/Database/@name"/> – database documentation</title>

			    <link href="{$resources}/favicon.ico" rel="icon"/>
			    <link href="{$resources}/favicon.ico" rel="shortcut icon"/>
          <link rel="stylesheet" href="{$resources}/lib/Google Fonts/style.css"/>
          <link rel="stylesheet" href="{$resources}/lib/ERD/css/graph.css"/>
			    <link rel="stylesheet" href="{$resources}/css/jquery-ui-1.9.2.custom.min.css"/>
			    <link rel="stylesheet" href="{$resources}/css/default.css"/>
			    <link rel="stylesheet" href="{$resources}/css/layout.css"/>
			    <link rel="stylesheet" href="{$resources}/css/loader.css"/>
			    <link rel="stylesheet" href="{$resources}/css/table.css"/>
			    <link rel="stylesheet" href="{$resources}/css/tree.css"/>    
        	<link rel="stylesheet" href="{$resources}/css/htmlClass.css"/> 
        	<link rel="stylesheet" href="{$resources}/css/mobile.css"/>
        		<link rel="stylesheet" href="{$resources}/css/custom.css"/>

        	<xsl:comment><![CDATA[[if lt IE 9]>
		      <script src="{$resources}/lib/HTML5shiv/html5shiv.js"></script>
		      <![endif]]]></xsl:comment>
            
          </head>
          <body>
            <xsl:call-template name="header"/>
            <xsl:call-template name="main"/>
            <xsl:call-template name="footer"/>
            <xsl:call-template name="scripts"/>
          </body>
        </html>
    </xsl:template>

    <!-- Header -->
    <xsl:template name="header">
    	<nav id="nav" class="grid">
	        <div class="span12">
	        	<a href="#content/home" class="ajax" data-target="#right">
	        		<img src="{$resources}/img/logo.png"/>
	        	</a>

	        	<div class="menu"></div>
	        	<span class="docname"><xsl:value-of select="/DataDocumenter/Databases/Database/@name"/> – database documentation</span>
	        </div>
	    </nav>
    </xsl:template>

    <!-- Content -->
    <xsl:template name="main">
    	<div id="main" class="cf">
    		<xsl:call-template name="nav-tree"/>
    		<xsl:call-template name="content"/>
    	</div>
    </xsl:template>

	<!-- Navigation -->
	<xsl:template name="nav-tree">
		<div id="aside" class="resizable-left border-right"><div id="left">
			<xsl:choose>
				<xsl:when test="Databases/Database">
					<ul class="tree">
						<xsl:apply-templates select="Databases/Database"/>
					</ul>
				</xsl:when>
				<xsl:otherwise><strong> Error: </strong> not found databases. </xsl:otherwise>
			</xsl:choose>
		</div></div>
	</xsl:template>

	<!-- Navigation - folders -->
	<xsl:template match="Modules|Functions|Procedures|Tables|Views">
    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test="*"> expand </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <li class="{$class}">
    	<i class="icon-folder"></i>
    	<a class="ajax" data-target="#right" href="#{$content}/{@src}{$ext}"><xsl:value-of select="local-name()"/></a>
    	<ul style="display: none;">
    		<xsl:apply-templates select="*"/>
    	</ul>
    </li>
	</xsl:template>

	<!-- Navigation - objects -->
	<xsl:template match="Database|Module|Function|Procedure|Table|View">
		<xsl:variable name="class">
			<xsl:choose>
				<xsl:when test="*"> expand </xsl:when>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="icon">
			<xsl:choose>
				<xsl:when test="local-name() = 'Database'"> icon-database </xsl:when>
				<xsl:when test="local-name() = 'Module'"> icon-module </xsl:when>
				<xsl:when test="local-name() = 'Function'"> icon-function </xsl:when>
				<xsl:when test="local-name() = 'Procedure'"> icon-procedure </xsl:when>
				<xsl:when test="local-name() = 'Table'"> icon-table </xsl:when>
				<xsl:when test="local-name() = 'View'"> icon-view </xsl:when>
			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="local-name() = 'Database'">
				<li>
					<i class="{$icon}"></i>
					<a class="ajax" data-target="#right" href="#{$content}/{@src}{$ext}"><xsl:value-of select="@name"/></a>
					<ul>
						<xsl:apply-templates select="*"/>
					</ul>
				</li>
			</xsl:when>
			<xsl:otherwise>
				<li class="{$class}">
					<i class="{$icon}"></i>
					<a class="ajax" data-target="#right" href="#{$content}/{@src}{$ext}"><xsl:value-of select="@name"/></a>
					<ul style="display: none;">
						<xsl:apply-templates select="*"/>
					</ul>
				</li>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Content -->
	<xsl:template name="content">
		<div id="content" class="resizable-right"><div id="right"></div></div>
	</xsl:template>

    <!-- Footer -->
    <xsl:template name="footer">
    	<footer id="footer">
			<span style="float:right"> Generated with <strong><a href="{Global/Product/@src}"><xsl:value-of select="Global/Product"/></a></strong></span>
		</footer>
    </xsl:template>

    <!-- Extra scripts -->
    <xsl:template name="scripts">
    	<div id="popup-error"> Action cannot be finished </div>
    	<div id="binding"></div>

    	<!--[if lt IE 9]>
	  	<script src="http://ie7-js.googlecode.com/svn/version/2.1(beta4)/IE9.js"></script>
	  	<![endif]-->
	    <script src="{$resources}/js/jquery-1.11.3.min.js"></script>
	    <script src="{$resources}/js/jquery-ui-1.9.2.custom.min.js"></script>
	    <script src="{$resources}/js/loader.js"></script>
	    <script src="{$resources}/js/treeExpand.js"></script>
	    <script src="{$resources}/js/utilities.js"></script>
	    <script src="{$resources}/js/mobile.js"></script>
    </xsl:template>

</xsl:stylesheet>